<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Portugese(PT)
</name>

<description>
   <am>Portugese(PT) Language Meta-Package</am>
   <ar>Portugese(PT) Language Meta-Package</ar>
   <bg>Portugese(PT) Language Meta-Package</bg>
   <ca>Meta-paquet de llengua per Portuguès (PT)</ca>
   <cs>Portugese(PT) Language Meta-Package</cs>
   <da>Portugisisk (portugal) sprog-metapakke</da>
   <de>Portugiesisches (PT) Sprach-Meta-Paket</de>
   <el>Πορτογαλική γλώσσα</el>
   <en>Portugese(PT) Language Meta-Package</en>
   <es>Portugese(PT) Language Meta-Package</es>
   <et>Portugese(PT) Language Meta-Package</et>
   <eu>Portugese(PT) Language Meta-Package</eu>
   <fa>Portugese(PT) Language Meta-Package</fa>
   <fi>Portugese(PT) Language Meta-Package</fi>
   <fr>Méta-paquet pour langue portugaise (PT)</fr>
   <he_IL>Portugese(PT) Language Meta-Package</he_IL>
   <hi>Portugese(PT) Language Meta-Package</hi>
   <hr>Portugese(PT) Language Meta-Package</hr>
   <hu>Portugese(PT) Language Meta-Package</hu>
   <id>Portugese(PT) Language Meta-Package</id>
   <is>Portugese(PT) Language Meta-Package</is>
   <it>Meta-pacchetto della lingua portoghese(PT)</it>
   <ja_JP>Portugese(PT) Language Meta-Package</ja_JP>
   <ja>Portugese(PT) Language Meta-Package</ja>
   <kk>Portugese(PT) Language Meta-Package</kk>
   <ko>Portugese(PT) Language Meta-Package</ko>
   <lt>Portugese(PT) Language Meta-Package</lt>
   <mk>Portugese(PT) Language Meta-Package</mk>
   <nb>Portugese(PT) Language Meta-Package</nb>
   <nl>Portugese(PT) Taal Meta-Pakket</nl>
   <pl>Portugalski (PT) metapakiet językowy</pl>
   <pt_BR>Português(PT) Meta-Pacote de Idioma</pt_BR>
   <pt>Português(PT) Meta-Pacote de Idioma</pt>
   <ro>Portugese(PT) Language Meta-Package</ro>
   <ru>Portugese(PT) Language Meta-Package</ru>
   <sk>Portugese(PT) Language Meta-Package</sk>
   <sl>Portugese(PT) Language Meta-Package</sl>
   <sq>Portugese(PT) Language Meta-Package</sq>
   <sr>Portugese(PT) Language Meta-Package</sr>
   <sv>Portugisiskt(PT) Språk Meta-Paket </sv>
   <tr>Portugese(PT) Language Meta-Package</tr>
   <uk>Portugese(PT) Language Meta-Package</uk>
   <zh_CN>Portugese(PT) Language Meta-Package</zh_CN>
   <zh_TW>Portugese(PT) Language Meta-Package</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
aspell-pt-pt
myspell-pt-pt
manpages-pt
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
aspell-pt-pt
myspell-pt-pt
manpages-pt
</uninstall_package_names>
</app>
